@@ -6,11 +6,11 @@ external) plugin hooks.
 
 import logging as _logging
 
-from .hush import get_secret
+from .core import Hush, get_secret
 
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
